@@ -3,7 +3,7 @@
 /**
  * Driver.php
  *
- * PHP Version 4
+ * PHP Version 5
  *
  * Copyright (c) 1997-2008 The PHP Group
  *
@@ -17,13 +17,13 @@
  *
  * Authors:   Carsten Lucke <luckec@tool-garage.de>
  *
- * CVS file id: $Id: Driver.php 321620 2011-12-31 20:59:14Z danielc $
+ * CVS file id: $Id$
  *
  * @category Date
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Driver.php 321620 2011-12-31 20:59:14Z danielc $
+ * @version  CVS: $Id$
  * @link     http://pear.php.net/package/Date_Holidays
  */
 
@@ -35,7 +35,7 @@
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Driver.php 321620 2011-12-31 20:59:14Z danielc $
+ * @version  CVS: $Id$
  * @link     http://pear.php.net/package/Date_Holidays
  */
 
@@ -119,7 +119,7 @@ define('DATE_HOLIDAYS_DRIVER_IDENTIFY_ISO3166_METHOD', 'getISO3166Codes');
  * @subpackage Driver
  * @author     Carsten Lucke <luckec@tool-garage.de>
  * @license    http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version    CVS: $Id: Driver.php 321620 2011-12-31 20:59:14Z danielc $
+ * @version    CVS: $Id$
  * @link       http://pear.php.net/package/Date_Holidays
  */
 class Date_Holidays_Driver
@@ -301,13 +301,13 @@ class Date_Holidays_Driver
      */
     function addTranslation($locale)
     {
-        $data_dir = "/usr/obj/pear-Date-Holidays-0.21.6/fake-amd64/var/www/pear/data";
+        $data_dir = "/usr/obj/ports/pear-Date-Holidays-0.21.7/fake-sparc64/var/www/pear/data";
         $bestLocale = $this->_findBestLocale($locale);
         $matches = array();
         $loaded = false;
 
         if ($data_dir == '@'.'DATA-DIR'.'@') {
-            $data_dir = dirname(dirname(dirname(__FILE__))); 
+            $data_dir = dirname(dirname(dirname(__FILE__)));
             $stubdirs = array(
                 "$data_dir/lang/{$this->_driverName}/",
                 "$data_dir/lang/Christian/");
@@ -1017,26 +1017,18 @@ class Date_Holidays_Driver
             return Date_Holidays::getErrorStack();
         }
 
-        include_once 'XML/Unserializer.php';
-        $options = array('parseAttributes' => false,
-                         'attributesArray' => false,
-                         'keyAttribute'    => array('property' => 'id'),
-                         'forceEnum'       => array('holiday'));
-
         // unserialize the document
-        $unserializer = new XML_Unserializer($options);
-        $status       = $unserializer->unserialize($file, true);
+        $document = simplexml_load_file($file);
 
-        if (PEAR::isError($status)) {
-            return Date_Holidays::raiseError($status->getCode(),
-                                             $status->getMessage());
+        $content = array();
+        $content['holidays'] = array();
+        $content['holidays']['holiday'] = array();
+
+        $nodes = $document->xpath('//holiday');
+        foreach ($nodes as $node) {
+            $content['holidays']['holiday'][] = (array)$node;
         }
 
-        $content = $unserializer->getUnserializedData();
-        if (PEAR::isError($content)) {
-            return Date_Holidays::raiseError($content->getCode(),
-                                             $content->getMessage());
-        }
         return $this->_addTranslationData($content, $locale);
     }
 
